<?php

namespace Drupal\Tests\sendgrid\Functional;

use Drupal\Core\Url;
use Drupal\sendgrid\SendgridHandlerInterface;

/**
 * Tests that all provided admin pages are reachable.
 *
 * @group sendgrid
 */
class SettingsFormTest extends SendgridFunctionalTestBase {

  /**
   * Tests admin pages provided by sendgrid.
   */
  public function testSettingsFormSubmit() {
    $admin_user = $this->drupalCreateUser($this->permissions);
    $this->drupalLogin($admin_user);

    $this->drupalGet(Url::fromRoute('sendgrid.settings_form'));

    // Make sure that "API Key" field is visible and required.
    $api_key_field = $this->assertSession()->elementExists('css', 'input[name="api_key"]');
    $this->assertTrue($api_key_field->hasAttribute('required'));

    // Save additional parameters. Check that all fields available on the form.
    $field_values = [
      'api_key' => '123456789-abc',
      'debug_mode' => TRUE,
      'ip_pool_name' => '',
      'use_theme' => TRUE,
      'format_filter' => '',
    ];
    $this->submitSettingsForm($field_values, 'The configuration options have been saved.');

    // Rebuild config values after form submit.
    $this->sendgridConfig = $this->config(SendgridHandlerInterface::CONFIG_NAME);

    // Test that all field values are stored in configuration.
    foreach ($field_values as $field_name => $field_value) {
      $this->assertEquals($field_value, $this->sendgridConfig->get($field_name));
    }
  }

  /**
   * Submits sendgrid settings form with given values and checks status message.
   */
  private function submitSettingsForm(array $values, $result_message) {
    foreach ($values as $field_name => $field_value) {
      $this->getSession()->getPage()->fillField($field_name, $field_value);
    }
    $this->getSession()->getPage()->pressButton('Save configuration');
    $this->assertSession()->pageTextContains($result_message);
  }

}
